# Singularity Compose

[![status](http://joss.theoj.org/papers/1fc2593b11b5e18df12efb59ed8757a0/status.svg)](http://joss.theoj.org/papers/1fc2593b11b5e18df12efb59ed8757a0)
[![DOI](https://zenodo.org/badge/188852712.svg)](https://zenodo.org/badge/latestdoi/188852712)

This is a simple orchestration library for Singularity containers, akin to
Docker Compose. See the [specification](https://singularityhub.github.io/singularity-compose/#/spec/spec-1.0) 
and the [documentation](https://singularityhub.github.io/singularity-compose) for
details, or more examples below.

## Examples

See our [Singularity Compose Examples](https://www.github.com/singularityhub/singularity-compose-examples) repository for
finding or contributing examples for using scompose.
